@@ -29,11 +29,5 @@ def plugme(app_config, options):
 
         return app
 
-    if not app_config.use_toscawidgets:
-        app_config.use_toscawidgets = True
-
-    if getattr(app_config, 'prefer_toscawidgets2', False):
-        raise Exception("Smallpress can't work with prefer_toscawidgets2 option, please change it to use_toscatiwdgets2 = True")
-
     app_config.register_hook('before_config', init_whoosh)
     return dict(appid='smallpress', global_helpers=False)
