@@ -25,6 +25,8 @@ from tgext.ajaxforms.ajaxform import formexpose
 from tgext.tagging.controllers import TaggingController
 from tgext.crud import EasyCrudRestController
 
+AttachmentType = config.get('_smallpress',{}).get('attachment_type', AttachedFile)
+
 try:
     import whoosh
     from whoosh.query import *
@@ -187,7 +189,7 @@ class RootController(TGController):
     def attach(self, **kw):
         article = DBSession.query(Article).get(kw['article'])
         attachment = Attachment(name=kw['name'], article=article,
-                                content=AttachedFile(kw['file'].file, kw['file'].filename))
+                                content=AttachmentType(kw['file'].file, kw['file'].filename))
         DBSession.add(attachment)
         DBSession.flush()
 
