@@ -1,5 +1,6 @@
 from tg import request, config
 
+import tg
 from sqlalchemy import Table, ForeignKey, Column
 from sqlalchemy.types import Unicode, Integer, DateTime
 from sqlalchemy.orm import backref, relation
@@ -7,9 +8,9 @@ from sqlalchemy.orm.interfaces import MapperExtension
 
 import os
 from datetime import datetime
+from tgext.datahelpers.fields import Attachment as DatahelpersAttachment, AttachedFile
 from smallpress.model import DeclarativeBase, DBSession
 from tgext.pluggable import app_model, primary_key
-from tgext.datahelpers.fields import Attachment as DataHelpersAttachment
 from tgext.pluggable import call_partial
 
 import mimetypes
@@ -33,6 +34,8 @@ try:
 except ImportError:
     sqla_events = False
 
+AttachmentType = tg.config.get('_smallpress',{}).get('attachment_type', AttachedFile)
+
 class Blog(DeclarativeBase):
     __tablename__ = 'smallpress_blogs'
 
@@ -164,7 +167,7 @@ class Attachment(DeclarativeBase):
 
     uid = Column(Integer, autoincrement=True, primary_key=True)
     name = Column(Unicode(16), nullable=False)
-    content = Column(DataHelpersAttachment)
+    content = Column(DatahelpersAttachment(AttachmentType))
 
     article_id = Column(Integer, ForeignKey(Article.uid))
     article = relation(Article, backref=backref('attachments', cascade='all, delete-orphan'))
